@@ -2,7 +2,7 @@
  * File: chat.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: chat.c 5572 2006-10-14 10:32:58Z andreasr $
+ * $Id: chat.c 6288 2007-05-19 09:00:39Z andreasr $
  *
  * This file contains all functions that are chat related.
  *
@@ -47,7 +47,14 @@
 #  include <winsock.h>
 #endif
 
+/* Supposedly not present on some systems (solaris). */
+#ifndef INADDR_NONE
+#  define INADDR_NONE ((unsigned long) -1)
+#endif
+
 #include <glib.h>
+#include <gnome.h>
+#include <libgnome/libgnome.h>
 
 #include "chat.h"
 #include "client.h"
@@ -699,6 +706,8 @@ int chat_checkurl(GtkXText *xtext, char *word)
 void chat_word_clicked(GtkXText *xtext, char *word,
         GdkEventButton *event)
 {
+	GError *err = NULL;
+
 	switch(chat_checkurl(xtext, word))
 	{
 		case WORD_GGZ:
@@ -706,7 +715,7 @@ void chat_word_clicked(GtkXText *xtext, char *word,
 			break;
 		case WORD_HOST:
 		case WORD_URL:
-			support_goto_url(word);
+			 gnome_url_show (word, &err);
 			break;
 		default:
 			break;
