@@ -1,5 +1,5 @@
 import sys
-import gettext
+from gettext import gettext as _
 import traceback
 import gobject
 import gtk
@@ -10,24 +10,22 @@ import glchess.chess
 import glchess.game
 
 # Optionally use OpenGL support
-# gtk.gtkgl throws RuntimeError when there is no OpenGL support
-# It should really just throw ImportError
 try:
     import gtk.gtkgl
     import OpenGL.GL
-except (ImportError, RuntimeError):
+except:
     haveGLSupport = False
 else:
     haveGLSupport = True
 
 __all__ = ['GtkView']
 
-pieceNames = {glchess.chess.board.PAWN:   gettext.gettext('pawn'),
-              glchess.chess.board.ROOK:   gettext.gettext('rook'),
-              glchess.chess.board.KNIGHT: gettext.gettext('knight'),
-              glchess.chess.board.BISHOP: gettext.gettext('bishop'),
-              glchess.chess.board.QUEEN:  gettext.gettext('queen'),
-              glchess.chess.board.KING:   gettext.gettext('king')}
+pieceNames = {glchess.chess.board.PAWN:   _('pawn'),
+              glchess.chess.board.ROOK:   _('rook'),
+              glchess.chess.board.KNIGHT: _('knight'),
+              glchess.chess.board.BISHOP: _('bishop'),
+              glchess.chess.board.QUEEN:  _('queen'),
+              glchess.chess.board.KING:   _('king')}
 
 class GtkViewArea(gtk.DrawingArea):
     """Custom widget to render an OpenGL scene"""
@@ -212,6 +210,11 @@ class GtkView(glchess.ui.ViewController):
     moveModel        = None
     selectedMove     = -1
     
+    showComments     = False
+    editingComment   = False
+    
+    gameResult       = None
+    
     # Flag to show if requesting attention
     requireAttention = False
 
@@ -221,7 +224,7 @@ class GtkView(glchess.ui.ViewController):
     whiteTime        = None
     blackTime        = None
     
-    def __init__(self, ui, title, feedback, isActive = True, moveFormat = 'human'):
+    def __init__(self, ui, title, feedback, isActive = True, moveFormat = 'human', showComments = False):
         """Constructor for a view.
         
         'feedback' is the feedback object for this view (extends ui.ViewFeedback).
@@ -233,6 +236,7 @@ class GtkView(glchess.ui.ViewController):
         self.feedback = feedback
         self.isActive = isActive
         self.moveFormat = moveFormat
+        self.showComments = showComments
         
         # The GTK+ elements
         self.gui = gtkui.loadGladeFile('chess_view.glade', 'chess_view')
@@ -240,20 +244,26 @@ class GtkView(glchess.ui.ViewController):
         self.widget = self.gui.get_widget('chess_view')
         self.viewWidget = GtkViewArea(self)
         self.gui.get_widget('view_container').add(self.viewWidget)
-        
+
         # Set the message panel to the tooltip style
         # (copied from Gedit)
         tooltip = gtk.Tooltips()
         tooltip.force_window()
         tooltip.tip_window.ensure_style()
         self.gui.get_widget('info_panel').set_style(tooltip.tip_window.get_style())
-        
-        # Make a model for navigation
+
+        # Make a model for navigation (move object, number, description) 
         model = gtk.ListStore(gobject.TYPE_PYOBJECT, int, str)
         iter = model.append()
-        model.set(iter, 0, None, 1, 0, 2, gettext.gettext('Game Start'))
+        model.set(iter, 0, None, 1, 0, 2, _('Game Start'))
         self.moveModel = model
+        
+        # Tabs are enabled to make editing the UI easier
+        self.gui.get_widget('comment_notebook').set_show_tabs(False)
+        
+        self.updateInfoPanel()
 
+        self.widget.show()
         self.viewWidget.show_all()
         
     def _on_info_panel_expose_event(self, widget, event):
@@ -262,6 +272,89 @@ class GtkView(glchess.ui.ViewController):
         widget.style.paint_flat_box(widget.window, gtk.STATE_NORMAL, gtk.SHADOW_OUT, None, widget, "tooltip",
                                     allocation.x, allocation.y, allocation.width, allocation.height)
 
+    def _on_comment_edit_button_toggled(self, widget):
+        """Gtk+ callback"""
+        label = self.gui.get_widget('panel_description_label')
+        entry = self.gui.get_widget('comment_text')
+        buffer = entry.get_buffer()
+        
+        move = self._getCurrentMove()
+        
+        # FIXME
+        if move is None:
+            return
+        
+        self.editingComment = widget.get_active()
+        if self.editingComment:
+            buffer.set_text(move.comment)
+            entry.grab_focus()
+            page = 1
+        else:
+            comment = buffer.get_text(buffer.get_start_iter(), buffer.get_end_iter())
+            
+            # FIXME: This should be notified so the game is considered modified for saving purposes
+            # self.feedback.setComment(move, comment)
+
+            move.comment = comment
+            label.set_text(comment)
+            buffer.set_text('')
+            page = 0
+        self.gui.get_widget('comment_notebook').set_current_page(page)
+
+    def _getCurrentMove(self):
+        if self.selectedMove == -1:
+            iter = self.moveModel.get_iter_from_string(str(len(self.moveModel) - 1))
+        else:
+            iter = self.moveModel.get_iter_from_string(str(self.selectedMove))
+        return self.moveModel.get_value(iter, 0)
+
+    def updateInfoPanel(self):
+        """
+        """
+        showPanel = False
+        
+        panel = self.gui.get_widget('info_panel')
+        titleLabel = self.gui.get_widget('panel_title_label')
+        descriptionLabel = self.gui.get_widget('panel_description_label')
+        
+        move = self._getCurrentMove()
+        if self.gameResult is not None:
+            (title, description) = self.gameResult
+            titleLabel.set_markup('<big><b>%s</b></big>' % title)
+            descriptionLabel.set_markup('<i>%s</i>' % description)
+            showPanel = True
+
+        editToggle = self.gui.get_widget('comment_edit_toggle')
+        if self.showComments:
+            # Show the comments
+            if move is None:
+                titleLabel.set_markup('<big><b>%s</b></big>' % _('Game start'))
+            else:
+                titleLabel.set_markup('<big><b>%s</b></big>' % self.generateMoveString(move))
+            
+            comment = _('No comment')
+            if move is not None and len(move.comment) > 0:
+                comment = move.comment
+
+            descriptionLabel.set_markup('<i>%s</i>' % comment)
+            editToggle.show()
+            showPanel = True
+        else:
+            editToggle.hide()
+
+        if showPanel:
+            panel.show()
+        else:
+            panel.hide()
+
+    def setShowComments(self, showComments):
+        """Enable comments on this view.
+        
+        'showComments' is true when move comments are visible.
+        """
+        self.showComments = showComments
+        self.updateInfoPanel()
+
     def setMoveFormat(self, format):
         """Set the format to display the moves in.
         
@@ -309,98 +402,109 @@ class GtkView(glchess.ui.ViewController):
     def generateMoveString(self, move):
         """
         """
-        if self.moveFormat == 'san':
-            string = '%2i. ' % ((move.number - 1) / 2 + 1)
-            if move.number % 2 == 0:
-                string += '... '
-            string += move.sanMove
-            return string
-        
-        if self.moveFormat == 'lan':
-            string = '%2i. ' % ((move.number - 1) / 2 + 1)
-            if move.number % 2 == 0:
-                string += '... '
-            string += move.canMove
-            return string
-        
-        colour = gettext.gettext('White')
-        victimColour = gettext.gettext('Black')
+        subs = {'movenum': (move.number - 1) / 2 + 1,
+                'move_can': move.canMove, 'move_san': move.sanMove,
+                'piece': pieceNames[move.piece.getType()],
+                'start': move.start, 'end': move.end}
+        if move.victim is not None:
+            subs['victim_piece'] = pieceNames[move.victim.getType()]
+        subs['colour'] = _('White')
+        subs['victim_colour'] = _('Black')
         if move.number % 2 == 1:
-            shortColour = 'a'
+            subs['short_colour'] = 'a'
         else:
-            shortColour = 'b'
-            t = colour
-            colour = victimColour
-            victimColour = t
-        string = '%2i%s.' % ((move.number - 1) / 2 + 1, shortColour)
-
-        if move.sanMove.startswith('O-O-O'):
-            string += ' %s castles long' % colour
-        elif move.sanMove.startswith('O-O'):
-            string += ' %s castles short' % colour
-        elif move.victim is not None:
-            string += ' %s %s at %s takes %s %s at %s' % \
-                      (colour, pieceNames[move.piece.getType()],
-                       move.start, victimColour, pieceNames[move.victim.getType()], move.end)
-        else:
-            string += ' %s %s moves from %s to %s' % (colour, pieceNames[move.piece.getType()], move.start, move.end)
-
-        # FIXME: Promotion
+            subs['short_colour'] = 'b'
+            t = subs['colour']
+            subs['colour'] = subs['victim_colour']
+            subs['victim_colour'] = t
+        
+        if self.moveFormat == 'san':
+            if move.number % 2 == 0:
+                return '%(movenum)2i. ... %(move_san)s' % subs
+            else:
+                return '%(movenum)2i. %(move_san)s' % subs
 
+        if self.moveFormat == 'lan':
+            string = '%(movenum)2i. ' % subs
+            if move.number % 2 == 0:
+                return '%(movenum)2i. ... %(move_can)s' % subs
+            else:
+                return '%(movenum)2i. %(move_can)s' % subs
+            
+        status = None
         if move.opponentInCheck:
             if move.opponentCanMove:
-                string += ' - ' + gettext.gettext('Check')
+                status = _('Check')
             else:
-                string += ' - ' + gettext.gettext('Checkmate')
+                status = _('Checkmate')
         elif not move.opponentCanMove:
-            string += ' - ' + gettext.gettext('Stalemate')
+            status = _('Stalemate')
+        if status is not None:
+            subs['suffix'] = _(' - %(check_status)s') % {'check_status': status}
+        else:
+            subs['suffix'] = ''
+
+        if move.sanMove.startswith('O-O-O'):
+            string = _('%(movenum)2i%(short_colour)s. %(colour)s castles long%(suffix)s') % subs
+        elif move.sanMove.startswith('O-O'):
+            string = _('%(movenum)2i%(short_colour)s. %(colour)s castles short%(suffix)s') % subs
+        elif move.victim is not None:
+            string = _('%(movenum)2i%(short_colour)s. %(colour)s %(piece)s at %(start)s takes %(victim_colour)s %(victim_piece)s at %(end)s%(suffix)s') % subs
+        else:
+            string = _('%(movenum)2i%(short_colour)s. %(colour)s %(piece)s moves from %(start)s to %(end)s%(suffix)s') % subs
+
+        # FIXME: Promotion
 
         return string
 
     def addMove(self, move):
-        """Extends glchess.ui.ViewController"""
+        """Extends glchess.ui.ViewController"""        
         # FIXME: Make a '@ui' player who watches for these itself?
         iter = self.moveModel.append()
         string = self.generateMoveString(move)
         self.moveModel.set(iter, 0, move, 1, move.number, 2, string)
-        
+
         # If is the current view and tracking the game select this
         if self.selectedMove == -1:
+            # If editing comments don't stay on current move
+            if self.editingComment:
+                self._setMoveNumber(move.number - 1)
+                return
+            
             self.ui._updateViewButtons()
-        
+
     def endGame(self, game):
         # If game completed show this in the GUI
         if game.result is glchess.game.RESULT_WHITE_WINS:
-            title = gettext.gettext('%s wins') % game.getWhite().getName()
+            title = _('%s wins') % game.getWhite().getName()
         elif game.result is glchess.game.RESULT_BLACK_WINS:
-            title = gettext.gettext('%s wins') % game.getBlack().getName()
+            title = _('%s wins') % game.getBlack().getName()
         else:
-            title = gettext.gettext('Game is drawn')
+            title = _('Game is drawn')
 
         description = ''
         if game.rule is glchess.game.RULE_CHECKMATE:
-            description = gettext.gettext('Opponent is in check and cannot move (checkmate)')
+            description = _('Opponent is in check and cannot move (checkmate)')
         elif game.rule is glchess.game.RULE_STALEMATE:
-            description = gettext.gettext('Opponent cannot move (stalemate)')
+            description = _('Opponent cannot move (stalemate)')
         elif game.rule is glchess.game.RULE_FIFTY_MOVES:
-            description = gettext.gettext('No piece has been taken or pawn moved in the last fifty moves')
+            description = _('No piece has been taken or pawn moved in the last fifty moves')
         elif game.rule is glchess.game.RULE_TIMEOUT:
-            description = gettext.gettext('Opponent has run out of time')
+            description = _('Opponent has run out of time')
         elif game.rule is glchess.game.RULE_THREE_FOLD_REPETITION:
-            description = gettext.gettext('The same board state has occured three times (three fold repetition)')
+            description = _('The same board state has occured three times (three fold repetition)')
         elif game.rule is glchess.game.RULE_INSUFFICIENT_MATERIAL:
             if game.result is glchess.game.RESULT_DRAW:
-                description = gettext.gettext('Neither player can cause checkmate (insufficient material)')
+                description = _('Neither player can cause checkmate (insufficient material)')
             else:
-                description = gettext.gettext('Opponent is unable to cause checkmate (insufficient material)')
+                description = _('Opponent is unable to cause checkmate (insufficient material)')
         elif game.rule is glchess.game.RULE_RESIGN:
-            description = gettext.gettext('One of the players has resigned')
+            description = _('One of the players has resigned')
         elif game.rule is glchess.game.RULE_DEATH:
-            description = gettext.gettext('One of the players has died')
+            description = _('One of the players has died')
 
-        self.gui.get_widget('panel_title_label').set_markup('<big><b>%s</b></big>' % title)
-        self.gui.get_widget('panel_description_label').set_markup('<i>%s</i>' % description)
-        self.gui.get_widget('info_panel').show()
+        self.gameResult = (title, description)
+        self.updateInfoPanel()
     
     def close(self):
         """Extends glchess.ui.ViewController"""
@@ -414,7 +518,7 @@ class GtkView(glchess.ui.ViewController):
         """
         """
         return (self.moveModel, self.selectedMove)
-        
+
     def _setMoveNumber(self, moveNumber):
         """Set the move number this view requests.
         
@@ -423,3 +527,4 @@ class GtkView(glchess.ui.ViewController):
         self.selectedMove = moveNumber
         if self.feedback is not None:
             self.feedback.setMoveNumber(moveNumber)
+        self.updateInfoPanel()
