@@ -279,13 +279,12 @@ on_network_game (void)
 
   ggz_gtk_initialize (FALSE,
 		      ggz_connected, ggz_game_launched, ggz_closed,
-		      NETWORK_ENGINE, NETWORK_VERSION, "GNOME GGZ");
+		      NETWORK_ENGINE, NETWORK_VERSION, "gnect.xml",
+		      "GGZ Gaming Zone");
 
   pwent = getpwuid(getuid());
   ggz_embed_ensure_server ("GGZ Gaming Zone", "gnome.ggzgamingzone.org",
 			   5688, pwent->pw_name);
-  ggz_embed_ensure_server ("GNOME GGZ", "games.gnome.org",
-			   5688, pwent->pw_name);
 
   ggzbox = ggz_gtk_create_main_area (app);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), ggzbox, NULL);
