@@ -3,9 +3,8 @@ import errno
 import gettext
 
 APP_DATA_DIR = os.path.join('/usr/local', 'share') 
-ICON_DIR =     os.path.join(APP_DATA_DIR,'pixmaps')
-IMAGE_DIR = os.path.join(ICON_DIR,'gnome-sudoku')
-LOCALEDIR 	= os.path.join(APP_DATA_DIR, 'locale')
+IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
+LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
 GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
 BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
 
@@ -17,8 +16,9 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.18.2.1"
+VERSION = "2.19.4"
 APPNAME = _("GNOME Sudoku")
+APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
 DESCRIPTION = _('GNOME Sudoku is a simple sudoku generator and player.  Sudoku is a japanese logic puzzle.')
 AUTHORS = ["Thomas M. Hinkle"]
@@ -46,4 +46,4 @@ def initialize_games_dir ():
         os.makedirs(DATA_DIR)
     except OSError, e:
         if e.errno != errno.EEXIST:
-            print 'Unable to make data directory %(dir)s: %(error)s' % {'dir': DATA_DIR, 'error': e.strerror}
+            print _('Unable to make data directory %(dir)s: %(error)s') % {'dir': DATA_DIR, 'error': e.strerror}
